@@ -265,16 +265,18 @@ class Choices(View):
 
 class DelayedValue(View):
     def get(self, request, app_label=None, actor=None, pk=None, field=None, **kw):
-        ar = action_request(
-            app_label, actor, request, request.GET, False,
-            renderer=settings.SITE.plugins.react.renderer)
+        rpt = requested_actor(app_label, actor)
+        # ar = action_request(
+        #     app_label, actor, request, request.GET, False,
+        #     renderer=settings.SITE.plugins.react.renderer)
         # print("20210619a", ar)
         # rpt = requested_actor(app_label, actor)
-        rpt = ar.actor
+        # rpt = ar.actor
         de = rpt.get_data_elem(field)
         if de is None:
             v = "{} has no data element {}".format(rpt, field)
         else:
+            ar = rpt.request(request=request)
             if pk == '-99998':
                 row = None
             else:
